// App for sending image files to a PHP file upload server. The idea is that
// if it is invoked from a "share" action, it just sends the damn file,
// if it is invoked as an app, it allows you to configure the server to
// send to.
//
// Code from: http://twigstechtips.blogspot.com/2011/10/android-sharing-images-or-files-through.html
//

package my.lan.zooty.upwithphp;

import android.app.Activity;
import android.os.Bundle;
import android.content.Intent;
import android.net.Uri;
import android.widget.Button;
import android.view.View;
import android.widget.TextView;
import android.preference.PreferenceManager;
import android.content.SharedPreferences;
import java.util.Set;
import android.app.ProgressDialog;
import android.util.Log;

public class UpWithPhpActivity extends Activity
{
   String Tag="UpWithPhpActivity";
   ProgressDialog pd = null;

   /** Called when the activity is first created. */
   @Override
   public void onCreate(Bundle savedInstanceState)
   {
      super.onCreate(savedInstanceState);
      setContentView(R.layout.main);

      ((Button) findViewById(R.id.config_button)).setOnClickListener(
         new Button.OnClickListener() {
            @Override public void onClick(View v) {
               updatePhpPrefs();
            } });

      Log.i(Tag,"In onCreate");
      Intent intent = getIntent();
      Bundle extras = intent.getExtras();
      String action = intent.getAction();

      // if this is from the share menu
      if (Intent.ACTION_SEND.equals(action)) {

         // Dump info about extras to logcat so I can find out what I'm
         // not handling if something doesn't work.

         Log.i(Tag,"saw action send");
         Set<String> keys = extras.keySet();
         for (String key : keys) {
            Object o = extras.get(key);
            String typeName = o.getClass().getName();
            Log.i(Tag,"intent has extra " + key + " type " + typeName);
            if (typeName.compareTo("java.lang.String") == 0) {
               String keyVal = extras.getString(key);
               Log.i(Tag,"   string value is " + keyVal);
            }
         }
         SharedPreferences prefs =
            PreferenceManager.getDefaultSharedPreferences(this);
         String url = prefs.getString("upload_host_edit_key", "");
         if (extras.containsKey(Intent.EXTRA_STREAM)) {
            // Get resource path
            Log.i(Tag,"saw extra stream");
            Uri uri = (Uri) extras.getParcelable(Intent.EXTRA_STREAM);
            Log.i(Tag,"got uri: " + uri);

            boolean downcase =
               prefs.getBoolean("downcase_name_checkbox_key", true);
            (new Thread(new UploadFileToPhp(this,
                                            url,
                                            downcase,
                                            uri,
                                            null))).start();
         } else if (extras.containsKey(Intent.EXTRA_TEXT)) {
            Log.i(Tag,"saw extra text");
            String textVal = extras.getString(Intent.EXTRA_TEXT);
            (new Thread(new UploadFileToPhp(this,
                                            url,
                                            false,
                                            null,
                                            textVal))).start();
         }
      }
   }

   @Override
   protected void onResume() {
      super.onResume();
      // Summarize the current prefs and record in text area.
      SharedPreferences prefs =
         PreferenceManager.getDefaultSharedPreferences(this);
      String url = prefs.getString("upload_host_edit_key", "");
      boolean downcase = prefs.getBoolean("downcase_name_checkbox_key", true);
      if (url == "") {
         String msg = getResources().getString(R.string.msg_no_host);
      } else {
         String dc;
         if (downcase) {
            dc = getResources().getString(R.string.downcase_name_checkbox_summary);
         } else {
            dc = getResources().getString(R.string.msg_keep_case);
         }
         String msg = getResources().getString(R.string.msg_upload_to) +
                         "\n" + url + "\n" + dc;
         ((TextView) findViewById(R.id.msg_area)).setText(msg);
      }
   }

   void updatePhpPrefs() {
      Intent launchPreferencesIntent =
         new Intent().setClass(this, UpWithPhpPrefsActivity.class);
      startActivity(launchPreferencesIntent);
   }

   void doUploadStart(int totalUpdates, String uploadName) {
      Log.i(Tag,"calling ProgressDialog.show");
      pd = new ProgressDialog(this);
      pd.setMessage(uploadName);
      pd.setTitle("Uploading...");
      if (totalUpdates == 0) {
         pd.setProgressStyle(ProgressDialog.STYLE_SPINNER);
         pd.setIndeterminate(true);
      } else {
         pd.setProgressStyle(ProgressDialog.STYLE_HORIZONTAL);
         pd.setMax(totalUpdates);
         pd.setProgress(0);
         // pd.setProgressNumberFormat("");
         pd.setIndeterminate(false);
      }
      pd.show();
      Log.i(Tag,"called ProgressDialog.show");
   }

   void doUpdateProgress() {
      if (pd != null) {
         pd.incrementProgressBy(1);
      }
   }

   void doUploadComplete() {
      // PUT CODE HERE - good place to make progress dialog go away...
      if (pd != null) {
         Log.i(Tag,"calling ProgressDialog.dismiss");
         pd.dismiss();
         pd = null;
      }
      finish();
   }
}
